@@ -176,7 +176,10 @@ class Distribution:
 
         headers["filename"] = str(self.filename)
         headers["elg-resource-distribution-id"] = str(self.pk)
-        response = requests.post(CORPUS_DOWNLOAD_URL.format(domain=self.domain, id=self.corpus_id), headers=headers)
+        response = requests.post(
+            CORPUS_DOWNLOAD_URL.format(domain=self.domain, id=self.corpus_id),
+            headers=headers,
+        )
         if response.ok:
             return response.json()["s3-url"]
         print(not_downloadable)
@@ -288,6 +291,7 @@ class Corpus(Entity, NeedAuthentication):
         domain: str,
         use_cache: bool,
         cache_dir: str,
+        **kwargs,
     ):
         """
         Init a Corpus object with the corpus information
@@ -322,12 +326,18 @@ class Corpus(Entity, NeedAuthentication):
         if self.resource_type != "Corpus":
             raise NotCorpusException(self.id)
         self._authenticate(
-            auth_object=auth_object, auth_file=auth_file, scope=scope, use_cache=use_cache, cache_dir=cache_dir
+            auth_object=auth_object,
+            auth_file=auth_file,
+            scope=scope,
+            use_cache=use_cache,
+            cache_dir=cache_dir,
         )
         self.distributions = [
             Distribution.from_data(self.id, self.domain, data)
             for data in get_information(
-                id=id, obj=self.record, infos=["described_entity", "lr_subclass", "dataset_distribution"]
+                id=id,
+                obj=self.record,
+                infos=["described_entity", "lr_subclass", "dataset_distribution"],
             )
         ]
 
@@ -421,9 +431,12 @@ class Corpus(Entity, NeedAuthentication):
         Returns:
             elg.Corpus: Corpus object with authentication information.
         """
-        if entity.record is None:
+        if entity.record == None:
             entity.record = get_metadatarecord(
-                id=entity.id, domain=entity.domain, use_cache=use_cache, cache_dir=cache_dir
+                id=entity.id,
+                domain=entity.domain,
+                use_cache=use_cache,
+                cache_dir=cache_dir,
             )
         parameters = entity.__dict__
         parameters["auth_object"] = auth_object
