@@ -1,9 +1,55 @@
 from textwrap import TextWrapper
-from typing import List
+from typing import List, Union
 
 from .utils import get_domain, get_metadatarecord, map_metadatarecord_to_result
 
 
+class MetadataRecordObj:
+    def __init__(self, in_dict: dict):
+        if in_dict:
+            if isinstance(in_dict, MetadataRecordObj):
+                in_dict = in_dict.__dict__
+            assert isinstance(in_dict, dict), f"<{type(in_dict)} {in_dict}> is not a dict"
+            for key, val in in_dict.items():
+                if isinstance(val, (list, tuple)):
+                    setattr(
+                        self,
+                        key,
+                        [MetadataRecordObj(x) if isinstance(x, dict) else x for x in val],
+                    )
+                else:
+                    setattr(
+                        self,
+                        key,
+                        MetadataRecordObj(val) if isinstance(val, dict) else val,
+                    )
+
+    def __getitem__(self, key):
+        return getattr(self, key)
+
+    def get(self, key, value=None):
+        return self.__dict__.get(key, value)
+
+    def keys(self):
+        return self.__dict__.keys()
+
+    def values(self):
+        return self.__dict__.values()
+
+    def __eq__(self, other):
+        if other is None:
+            other = {}
+        elif isinstance(other, MetadataRecordObj):
+            other = other.__dict__
+        return self.__dict__ == other
+
+    def __repr__(self) -> str:
+        return str(self.__dict__)
+
+    def __str__(self) -> str:
+        return f"<MetadataRecordObj keys=[{', '.join(list(self.__dict__.keys()))}]>"
+
+
 class Entity:
     """
     Class to represent every ELG entity
@@ -29,12 +75,13 @@ class Entity:
         intended_applications: List[str],
         views: int,
         downloads: int,
-        size: int,
         service_execution_count: int,
         status: str,
         under_construction: bool,
         domain: str,
-        record: dict = None,
+        record: Union[dict, MetadataRecordObj] = None,
+        size: int = 0,
+        elg_compatible_service: bool = None,
         **kwargs,
     ):
         """Init an Entity object with the entity information"""
@@ -61,7 +108,8 @@ class Entity:
         self.status = status
         self.under_construction = under_construction
         self.domain = domain
-        self.record = record
+        self.record = MetadataRecordObj(record)
+        self.elg_compatible_service = elg_compatible_service
 
     def __str__(self):
         id_wrapper = TextWrapper(initial_indent="Id             ", width=70, subsequent_indent=" " * 15)
@@ -128,6 +176,7 @@ class Entity:
         domain: str = "live",
         use_cache: bool = True,
         cache_dir: str = "~/.cache/elg",
+        display_and_stat: bool = False,
     ):
         """
         Class method to init an Entity object from its id.
@@ -138,12 +187,19 @@ class Entity:
                 development ELG and another value to use a local ELG. Defaults to "live".
             use_cache (bool, optional): True if you want to use cached files. Defaults to True.
             cache_dir (str, optional): path to the cache_dir. Set it to None to not store any cached files. Defaults to "~/.cache/elg".
+            display_and_stat (bool, optional): True to obtain more information and stats about the entity
 
         Returns:
             elg.Entity: Entity object.
         """
         domain = get_domain(domain=domain)
-        record = get_metadatarecord(id=id, domain=domain, use_cache=use_cache, cache_dir=cache_dir)
-        result = map_metadatarecord_to_result(id, record)
+        record = get_metadatarecord(
+            id=id,
+            domain=domain,
+            use_cache=use_cache,
+            cache_dir=cache_dir,
+            display_and_stat=display_and_stat,
+        )
+        result = map_metadatarecord_to_result(id, record, display_and_stat=display_and_stat)
         result["domain"] = domain
         return cls(**result)
