@@ -1,6 +1,6 @@
 import inspect
 import json
-import re
+import sys
 from collections.abc import Iterable
 from pathlib import Path
 from typing import Dict, List
@@ -11,16 +11,17 @@ try:
     import docker
     from flask import Flask
     from flask import request as flask_request
-    from flask_json import JsonError
     from requests_toolbelt import MultipartDecoder
 except:
     raise ImportError(
         "Extra dependencies need to be install to use the FlaskService class. Please run: `pip install elg[flask]`."
     )
 
+
 from .model import (AudioRequest, Failure, Progress, ResponseObject,
-                    StructuredTextRequest, TextRequest)
-from .utils.docker import COPY_FOLDER, DOCKERFILE, ENTRYPOINT_FLASK
+                    StandardMessages, StructuredTextRequest, TextRequest)
+from .utils.docker import COPY_FOLDER, DOCKERFILE, ENTRYPOINT_FLASK, ENV_FLASK
+from .utils.json_encoder import json_encoder
 
 
 class FlaskService:
@@ -44,8 +45,42 @@ class FlaskService:
         self.app.config["JSON_ADD_STATUS"] = False
         # Don't sort properties alphabetically in response JSON
         self.app.config["JSON_SORT_KEYS"] = False
+        self.app.json_encoder = json_encoder(self)
         self.app.add_url_rule("/process", "process", self.process, methods=["POST"])
 
+    def to_json(self, obj):
+        """Hook that can be overridden by subclasses to customise JSON encoding.
+
+        FlaskService can convert the following types to JSON by default, in
+        addition to the types handled natively by `json.dump`:
+
+        - date, time, datetime (via `.isoformat()`)
+        - uuid.UUID (converted to `str`)
+        - any pydantic.BaseModel including the ELG message types (via
+          `.dict(by_alias=True, exclude_none=True)`)
+        - anything Iterable (as a list)
+        - any `dataclass` (converted to a `dict` via `dataclasses.asdict`)
+        - anything with a `__json__` or `for_json` method (which is expected to
+          return a serializable type)
+
+        To handle other types, or to change the standard behaviour for any of
+        the above types, subclasses can override this method, which will be
+        called whenever an object other than a string, number, bool, list or
+        dict must be serialized and is expected to return a JSON-serializable
+        object to be used in place of the original, or `None` to fall back to
+        the default behaviour.
+
+        The default implementation of this method always returns `None`.
+
+        Args:
+            obj: the object to convert
+
+        Returns:
+            a substitute object suitable for JSON serialization, or `None` to
+            use the default behaviour.
+        """
+        return None
+
     def run(self):
         """
         Method to start the flask app.
@@ -58,8 +93,8 @@ class FlaskService:
         """
         logger.info("Process request")
         even_stream = True if "text/event-stream" in flask_request.accept_mimetypes else False
-        logger.debug(f"Accept MimeTypes: {flask_request.accept_mimetypes}")
-        logger.info(f"Accept even-stream: {even_stream}")
+        logger.debug("Accept MimeTypes: {mimetypes}", mimetypes=flask_request.accept_mimetypes)
+        logger.debug("Accept even-stream: {even_stream}", even_stream=even_stream)
         if "application/json" in flask_request.content_type:
             data = flask_request.get_json()
         elif "multipart/form-data" in flask_request.content_type:
@@ -77,67 +112,74 @@ class FlaskService:
         else:
             raise ValueError()
 
-        logger.debug(f"Data type: {data.get('type')}")
-        if data.get("type") == "audio":
-            request = AudioRequest(**data)
-        elif data.get("type") == "text":
-            request = TextRequest(**data)
-        elif data.get("type") == "structuredText":
-            request = StructuredTextRequest(**data)
+        request_type = data.get("type")
+        logger.debug("Data type: {request_type}", request_type=request_type)
+        if request_type in ["audio", "text", "structuredText"]:
+            if request_type == "audio":
+                request = AudioRequest(**data)
+            elif request_type == "text":
+                request = TextRequest(**data)
+            else:
+                request = StructuredTextRequest(**data)
+            logger.trace("Call with the input: {request}", request=request)
+            try:
+                response = self.process_request(request)
+            except:
+                logger.opt(exception=True).warning("Error during the request processing.")
+                response = Failure(
+                    errors=[StandardMessages.generate_elg_service_internalerror(params=[str(sys.exc_info()[1])])]
+                )
         else:
-            self.invalid_request_error()
-        logger.info(f"Call with the input: {request}")
-        try:
-            response = self.process_request(request)
-        except:
-            logger.debug("Error during the request processing.")
-            response = Failure(
-                errors=[
-                    {"code": "elg.internalError", "text": "Internal error during processing", "params": ["message"]}
-                ]
-            )
+            response = Failure(errors=[StandardMessages.generate_elg_request_invalid()])
+
         if isinstance(response, Failure):
-            logger.info(f"Get error message: {response}")
-            response = {"failure": response.dict(by_alias=True)}
-            logger.info(f"Return: {response}")
+            logger.debug("Get error message")
+            response = {"failure": response}
+            logger.trace("Return: {response}", response=response)
+            logger.info("Response returned")
+            return response
         elif isinstance(response, ResponseObject):
-            logger.info(f"Get response: {response}")
-            response = {"response": response.dict(by_alias=True)}
-            logger.info(f"Return: {response}")
+            logger.debug("Get response")
+            response = {"response": response}
+            logger.trace("Return: {response}", response=response)
+            logger.info("Response returned")
             return response
         elif isinstance(response, Iterable):
-            logger.info(f"Get iterable response")
+            logger.debug("Get iterable response")
             if even_stream:
+                logger.info("Streaming response returned")
                 return self.app.response_class(self.generator_mapping(response), mimetype="text/event-stream")
             else:
                 response = self.get_response_from_generator(response)
-                logger.info(f"Get response: {response}")
-                response = {"response": response.dict(by_alias=True)}
-                logger.info(f"Return: {response}")
+                if isinstance(response, ResponseObject):
+                    logger.debug("Get response")
+                    response = {"response": response}
+                elif isinstance(response, Failure):
+                    logger.debug("Get error message")
+                    response = {"failure": response}
+                else:
+                    logger.debug("Response type not known")
+                    response = {"failure": Failure(errors=[StandardMessages.generate_elg_invalid_response()])}
+                logger.trace("Return: {response}", response=response)
+                logger.info("Response returned")
                 return response
         else:
             raise ValueError("Unknown returned type")
 
-    def invalid_request_error(self):
-        """
-        Generates a valid ELG "failure" response if the request cannot be parsed
-        """
-        raise JsonError(
-            status_=400, failure={"errors": [{"code": "elg.request.invalid", "text": "Invalid request message"}]}
-        )
-
     def process_request(self, request):
         """
         Method to process the request object. This method only calls the right process method regarding the type of the request.
         """
         if request.type == "text":
-            logger.info("Process text request")
+            logger.debug("Process text request")
             return self.process_text(request)
         elif request.type == "structuredText":
+            logger.debug("Process structuredText request")
             return self.process_structured_text(request)
         elif request.type == "audio":
+            logger.debug("Process audio request")
             return self.process_audio(request)
-        self.invalid_request_error()
+        return Failure(errors=[StandardMessages.generate_elg_request_invalid()])
 
     def process_text(self, request: TextRequest):
         """
@@ -166,44 +208,36 @@ class FlaskService:
         """
         raise NotImplementedError()
 
-    @staticmethod
-    def generator_mapping(generator):
+    def generator_mapping(self, generator):
         end = False
         try:
             for message in generator:
                 if end == True:
                     logger.warning(
-                        (
-                            "The service has already returned a ResponseObject or Failure message but continue to return the following message:\n"
-                            f"{message.dict(by_alias=True)}\nThis message will be ignored and not returned to the user."
-                        )
+                        "The service has already returned a ResponseObject or Failure message but continue to return a message. This message will be ignored and not returned to the user."
                     )
                     continue
                 if isinstance(message, Failure):
-                    logger.info(f"Get failure: {message}")
-                    message = json.dumps({"failure": message.dict(by_alias=True)})
+                    logger.debug("Get failure message")
+                    message = json.dumps({"failure": message}, cls=self.app.json_encoder)
                     end = True
                 elif isinstance(message, Progress):
-                    logger.info(f"Get progress: {message}")
-                    message = json.dumps({"progress": message.dict(by_alias=True)})
+                    logger.debug("Get progress message")
+                    message = json.dumps({"progress": message}, cls=self.app.json_encoder)
                 elif isinstance(message, ResponseObject):
-                    logger.info(f"Get response: {message}")
-                    message = json.dumps({"response": message.dict(by_alias=True)})
+                    logger.debug("Get response")
+                    message = json.dumps({"response": message}, cls=self.app.json_encoder)
                     end = True
                 yield f"data:{message}\r\n\r\n"
         except:
+            logger.opt(exception=True).warning("Exception in generator")
             message = json.dumps(
                 {
                     "failure": Failure(
-                        errors=[
-                            {
-                                "code": "elg.internalError",
-                                "text": "Internal error during processing",
-                                "params": ["message"],
-                            }
-                        ]
-                    ).dict(by_alias=True)
-                }
+                        errors=[StandardMessages.generate_elg_service_internalerror(params=[str(sys.exc_info()[1])])]
+                    )
+                },
+                cls=self.app.json_encoder,
             )
             yield f"data:{message}\r\n\r\n"
 
@@ -213,18 +247,13 @@ class FlaskService:
         for message in generator:
             if response is not None:
                 logger.warning(
-                    (
-                        "The service has already returned a ResponseObject or Failure message but continue to return the following message:\n"
-                        f"{message.dict(by_alias=True)}\nThis message will be ignored and not returned to the user."
-                    )
+                    "The service has already returned a ResponseObject or Failure message but continue to return a message. This message will be ignored and not returned to the user."
                 )
                 continue
             if isinstance(message, (ResponseObject, Failure)):
                 response = message
         if response is None:
-            return Failure(
-                errors=[{"code": "elg.response.invalid", "text": "Invalid response message", "params": ["message"]}]
-            )
+            return Failure(errors=[StandardMessages.generate_elg_invalid_response()])
         return response
 
     @classmethod
@@ -252,6 +281,10 @@ class FlaskService:
         commands: List[str] = [],
         base_image: str = "python:slim",
         path: str = None,
+        log_level: str = "INFO",
+        workers: int = 1,
+        timeout: int = 30,
+        worker_class: str = "sync",
     ):
         """Class method to create the correct Dockerfile.
 
@@ -261,6 +294,10 @@ class FlaskService:
             commands (List[str], optional): List off additional commands to run in the Dockerfile. Defaults to [].
             base_image (str, optional): Name of the base Docker image used in the Dockerfile. Defaults to 'python:slim'.
             path (str, optional): Path where to generate the file. Defaults to None.
+            log_level (str, optional): The minimum severity level from which logged messages should be displayed. Defaults to 'INFO'.
+            workers (int, optional): Number of Gunicorn workers. Defaults to 1.
+            timeout (int, optional): Timeout value for the Gunicorn worker. Defaults to 30.
+            worker_class (str, optional): Worker class value for the Gunicorn worker. Defaults to 'sync'.
         """
         if path == None:
             path = Path(inspect.getsourcefile(cls))
@@ -284,6 +321,9 @@ class FlaskService:
                     required_files=" ".join(required_files),
                     required_folders=required_folders,
                     commands="\n".join(commands),
+                    env=ENV_FLASK.format(
+                        workers=workers, timeout=timeout, worker_class=worker_class, log_level=log_level
+                    ),
                 )
             )
 
@@ -301,14 +341,27 @@ class FlaskService:
         return image
 
     @classmethod
-    def docker_push_image(cls, repository: str, tag: str, username: str = None, password: str = None, **kwargs):
+    def docker_push_image(
+        cls,
+        repository: str,
+        tag: str,
+        username: str = None,
+        password: str = None,
+        **kwargs,
+    ):
         """
         Class method to do `docker push ...` in python.
         """
         client = docker.from_env()
         if username is not None and password is not None:
             auth_config = {"username": username, "password": password}
-            client.images.push(repository=repository, tag=tag, auth_config=auth_config, stream=True, **kwargs)
+            client.images.push(
+                repository=repository,
+                tag=tag,
+                auth_config=auth_config,
+                stream=True,
+                **kwargs,
+            )
         client.images.push(repository=repository, tag=tag, stream=True, **kwargs)
         return
 
@@ -324,5 +377,11 @@ class FlaskService:
         push_kwargs: Dict = {},
     ):
         cls.docker_build_image(tag=f"{repository}:{tag}", pull=pull, **build_kwargs)
-        cls.docker_push_image(repository=repository, tag=tag, username=username, password=password, **push_kwargs)
+        cls.docker_push_image(
+            repository=repository,
+            tag=tag,
+            username=username,
+            password=password,
+            **push_kwargs,
+        )
         return None
