@@ -1,5 +1,5 @@
-from .base import (Annotation, Failure, Progress, Request, Response,
-                   ResponseObject, StatusMessage)
+from .base import (Annotation, Failure, Progress, Request, ResponseObject,
+                   StandardMessages, StatusMessage)
 from .request import AudioRequest, StructuredTextRequest, TextRequest
 from .response import (AnnotationsResponse, AudioResponse, ClassesResponse,
                        ClassificationResponse, TextsResponse,
