@@ -3,15 +3,16 @@ from typing import List
 from pydantic import BaseModel
 
 from .StatusMessage import StatusMessage
+from .utils import to_camel
 
 
 class Failure(BaseModel):
     """
     Details of a failed task
-
-    Attributes
-    ----------
-    errors: List[StatusMessage]: list of status messages describing failure
     """
 
     errors: List[StatusMessage]
+    """*(required)* List of status messages describing the failure"""
+
+    class Config:
+        alias_generator = to_camel
