@@ -2,6 +2,8 @@ from typing import Dict, List
 
 from pydantic import BaseModel
 
+from .utils import to_camel
+
 
 class StatusMessage(BaseModel):
     """
@@ -11,16 +13,19 @@ class StatusMessage(BaseModel):
     languages.  The text can contain numbered placeholders of the form <code>{0}</code>, which are filled in with values
     specified in the "params" property. The "text" property provides a single fallback text to be used if the specified
     code cannot be found in the lookup table.
-
-    Attributes
-    ----------
-    code: (str, required) status code to be found in lookup table
-    params: (List[str], required) values to fill in message placeholder
-    text: (str, requored) fallback text to be used if specified code cannot be found in lookup table
-    detail: (Dict, optional) arbitrary further details that don't need translation (e.g: stacktrace)
     """
 
     code: str
+    """*(required)* status code to be found in lookup table"""
+
     params: List[str]
+    """*(required)* values to fill in message placeholder"""
+
     text: str
+    """*(required)* fallback text to be used if specified code cannot be found in lookup table"""
+
     detail: Dict = None
+    """*(optional)* arbitrary further details that don't need translation (e.g. stacktrace)"""
+
+    class Config:
+        alias_generator = to_camel
