@@ -3,36 +3,36 @@ from typing import List
 from pydantic import BaseModel, Field
 
 from .. import ResponseObject
+from ..base.utils import to_camel
 
 
 class ClassesResponse(BaseModel):
     """
     Classification object: classification and score (optional likelihood of classification)
-
-    Attributes
-    ----------
-    class: (str, required) labelled class
-    score: (float, optional) confidence score in class
+    Subclass of :class:`elg.model.base.ResponseObject.ResponseObject`
     """
 
     class_field: str = Field(None, alias="class")
+    """*(required)* labelled class"""
+
     score: float = None
+    """*(optional)* confidence score in class"""
+
+    class Config:
+        alias_generator = to_camel
 
 
 class ClassificationResponse(ResponseObject):
     """
     Response encapsulating one or more classifications of the whole input message, optionally with confidence scores
     attached.
-
-    Attributes
-    ----------
-    type (string, required): type of response
-    warnings (List[StatusMessage], optional): messages describing any warnings on responses
-    classes: (List[ClassesResponse], optional) : list of classications, zero or more allowed
     """
 
     type: str = "classification"
+    """*(required)* type of response"""
+
     classes: List[ClassesResponse] = None
+    """*(optional)*  list of classifications, zero or more allowed"""
 
     def auto_content(self):
         if self.warnings is not None:
