@@ -21,7 +21,8 @@ from .model import (AudioRequest, Request, StructuredTextRequest, TextRequest,
                     get_response)
 from .utils import (MIME, get_argument_from_json, get_domain, get_information,
                     get_metadatarecord, map_metadatarecord_to_result)
-from .utils.errors import (DomainException, NotServiceException,
+from .utils.errors import (DomainException, NotElgServiceException,
+                           NotServiceException,
                            RefreshTokenExpirationException,
                            catch_requests_error, ensure_response_ok)
 
@@ -112,6 +113,7 @@ class Service(Entity, NeedAuthentication):
         domain: str,
         use_cache: bool,
         cache_dir: str,
+        **kwargs,
     ):
         """
         Init a Service object with the service information
@@ -145,7 +147,11 @@ class Service(Entity, NeedAuthentication):
         if self.resource_type != "ToolService" and self.resource_type != "Tool/Service":
             raise NotServiceException(self.id)
         self._authenticate(
-            auth_object=auth_object, auth_file=auth_file, scope=scope, use_cache=use_cache, cache_dir=cache_dir
+            auth_object=auth_object,
+            auth_file=auth_file,
+            scope=scope,
+            use_cache=use_cache,
+            cache_dir=cache_dir,
         )
         self._get_elg_execution_location()
 
@@ -239,9 +245,14 @@ class Service(Entity, NeedAuthentication):
         Returns:
             elg.Service: Service object with authentication information.
         """
-        if entity.record is None:
+        if not entity.elg_compatible_service:
+            raise NotElgServiceException(entity.id)
+        if entity.record == None:
             entity.record = get_metadatarecord(
-                id=entity.id, domain=entity.domain, use_cache=use_cache, cache_dir=cache_dir
+                id=entity.id,
+                domain=entity.domain,
+                use_cache=use_cache,
+                cache_dir=cache_dir,
             )
         parameters = entity.__dict__
         parameters["auth_object"] = auth_object
@@ -324,10 +335,14 @@ class Service(Entity, NeedAuthentication):
         Method to get the elg execution location information from the metadata record.
         """
         self.elg_execution_location_sync = get_information(
-            id=self.id, obj=self.record, infos=["service_info", "elg_execution_location_sync"]
+            id=self.id,
+            obj=self.record,
+            infos=["service_info", "elg_execution_location_sync"],
         )
         self.elg_execution_location = get_information(
-            id=self.id, obj=self.record, infos=["service_info", "elg_execution_location"]
+            id=self.id,
+            obj=self.record,
+            infos=["service_info", "elg_execution_location"],
         )
 
     @need_authentication()
@@ -349,7 +364,7 @@ class Service(Entity, NeedAuthentication):
         Args:
             request_input (Union[str, List[str], Request]): can be the text to process directly, the name of the file to process,
                 a list of texts, or directly a Request object.
-            request_type (str, optional): precise the type of the request. Can be "text", "structuredText", or "audio".
+            request_type (str, optional): precise the type of the request. Can be "text", "structuredText", "audio", or "audioStream".
                 It is only used if request_input is not a Request object. Defaults to "text".
             sync_mode (bool, optional): True to use the sync_mode. Defaults to False.
             timeout (int, optional): number of seconds before timeout. Defaults to None.
@@ -383,9 +398,11 @@ class Service(Entity, NeedAuthentication):
                     request = StructuredTextRequest.from_file(request_input)
                 elif request_type == "audio":
                     request = AudioRequest.from_file(request_input)
+                elif request_type == "audioStream":
+                    request = AudioRequest.from_file(request_input, streaming=True)
                 else:
                     raise ValueError(
-                        "Invalid value for request_type. It musts be 'text', 'structuredText', or 'audio'."
+                        "Invalid value for request_type. It musts be 'text', 'structuredText', 'audio', or 'audioStream'."
                     )
             else:
                 if request_type != "text":
@@ -435,12 +452,17 @@ class Service(Entity, NeedAuthentication):
                     ),
                     "application/json",
                 ),
-                "content": (None, request.content, "audio/x-wav" if request.format == "LINEAR16" else "audio/mpeg"),
+                "content": (
+                    None,
+                    request.content,
+                    "audio/x-wav" if request.format == "LINEAR16" else "audio/mpeg",
+                ),
             }
             data = None
             post_kwargs = {"files": files}
         elif isinstance(request, AudioRequest):
-            data = request.content
+            data = request.content if request.content else request.generator
+            post_kwargs["params"] = request.params
             headers["Content-Type"] = "audio/x-wav" if request.format == "LINEAR16" else "audio/mpeg"
         elif isinstance(request, TextRequest) or isinstance(request, StructuredTextRequest):
             data = json.dumps(request.dict())
@@ -448,10 +470,20 @@ class Service(Entity, NeedAuthentication):
         else:
             raise ValueError(f"Request type {type(request)} not recognized.")
         if sync_mode:
-            return self._call_sync(data=data, headers=headers, timeout=timeout, output_func=output_func, **post_kwargs)
+            return self._call_sync(
+                data=data,
+                headers=headers,
+                timeout=timeout,
+                output_func=output_func,
+                **post_kwargs,
+            )
         else:
             return self._call_async(
-                data=data, headers=headers, timeout=timeout, output_func=output_func, **post_kwargs
+                data=data,
+                headers=headers,
+                timeout=timeout,
+                output_func=output_func,
+                **post_kwargs,
             )
 
     @catch_requests_error
@@ -472,7 +504,11 @@ class Service(Entity, NeedAuthentication):
         """
         headers["Accept"] = "application/json"
         response = requests.post(
-            self.elg_execution_location_sync, headers=headers, data=data, timeout=timeout, **kwargs
+            self.elg_execution_location_sync,
+            headers=headers,
+            data=data,
+            timeout=timeout,
+            **kwargs,
         )
         ensure_response_ok(response)
         return output_func(get_response(response.json()))
@@ -493,7 +529,13 @@ class Service(Entity, NeedAuthentication):
         Returns:
             Union[Dict, str]: service response in JSON format or as a string if output_func returns a string.
         """
-        response = requests.post(self.elg_execution_location, headers=headers, data=data, timeout=timeout, **kwargs)
+        response = requests.post(
+            self.elg_execution_location,
+            headers=headers,
+            data=data,
+            timeout=timeout,
+            **kwargs,
+        )
         ensure_response_ok(response)
         response = response.json()["response"]
         assert response["type"] == "stored"
@@ -502,7 +544,9 @@ class Service(Entity, NeedAuthentication):
         response = requests.get(uri, headers=headers)
         waiting_time = time.time()
         while response.ok and "progress" in response.json().keys():
-            print(f"Progress: {response.json()['progress']['percent']}%")
+            percent = response.json()["progress"]["percent"]
+            if percent != 0:
+                print(f"Progress: {percent}%")
             sleep(1)
             response = requests.get(uri, headers=headers, timeout=timeout)
             if time.time() - waiting_time > (timeout if timeout is not None else float("inf")):
