@@ -1,5 +1,5 @@
 ENTRYPOINT_FLASK = """\
-#!/bin/sh\nexec /sbin/tini -- venv/bin/gunicorn --bind=0.0.0.0:8000 "--workers=$WORKERS" "--timeout=$TIMEOUT" --worker-tmp-dir=/dev/shm "$@" {service_script}:app\n"""
+#!/bin/sh\nexec /sbin/tini -- venv/bin/gunicorn --bind=0.0.0.0:8000 "--workers=$WORKERS" "--timeout=$TIMEOUT" "--worker-class=$WORKER_CLASS" --worker-tmp-dir=/dev/shm "$@" {service_script}:app\n"""
 
 ENTRYPOINT_QUART = """\
 #!/bin/sh\nexec /sbin/tini -- venv/bin/hypercorn --bind=0.0.0.0:8000 "$@" {service_script}:app\n"""
@@ -30,11 +30,21 @@ RUN venv/bin/pip --no-cache-dir install -r requirements.txt
 {required_folders}
 COPY --chown=elg:elg docker-entrypoint.sh {required_files} /elg/
 
-ENV WORKERS=1
-ENV TIMEOUT=30
+{env}
 
 RUN chmod +x ./docker-entrypoint.sh
 ENTRYPOINT ["./docker-entrypoint.sh"]\
 """
 
 COPY_FOLDER = "COPY --chown=elg:elg {folder_name} /elg/{folder_name}/"
+
+ENV_FLASK = """\
+ENV WORKERS={workers}
+ENV TIMEOUT={timeout}
+ENV WORKER_CLASS={worker_class}
+ENV LOGURU_LEVEL={log_level}
+"""
+
+ENV_QUART = """\
+ENV LOGURU_LEVEL={log_level}
+"""
